%define         pypiname          Cartopy
%define         srcname           cartopy

Name:           python-cartopy
Version:        0.24.1
Release:        %mkrel 3

Summary:        A Python package designed to draw maps
License:        LGPLv3
Group:          Development/Python

Url:            https://pypi.python.org/pypi/Cartopy
Source0:        %{pypi_source}

BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-numpy-devel
BuildRequires:  geos-devel
BuildRequires:  chrpath

%description
Cartopy is a Python package designed to make drawing maps for data
analysis and visualisation easy. Some of the key features of cartopy are:
* object oriented projection definitions
* point, line, vector, polygon and image transformations between projections
* integration to expose advanced mapping in matplotlib with a simple
  and intuitive interface
* powerful vector data handling by integrating shapefile reading with
  Shapely capabilities.

%package -n python3-cartopy
Summary:        Python3 implementation of Cartopy
Group:          Development/Python
%{?python_provide:%python_provide python3-cartopy}

%description -n python3-cartopy
Cartopy is a Python 3 package designed to make drawing maps for data
analysis and visualisation easy. Some of the key features of cartopy are:
* object oriented projection definitions
* point, line, vector, polygon and image transformations between projections
* integration to expose advanced mapping in matplotlib with a simple
  and intuitive interface
* powerful vector data handling by integrating shapefile reading with
  Shapely capabilities.


%prep
%autosetup -p1 -n %{srcname}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files cartopy

pushd %{buildroot}/%{python3_sitearch}/cartopy
for mod in $(find . -type f -name \*.so ); do
    chrpath --delete $mod
done
popd

%files -n python3-cartopy -f %{pyproject_files}
%doc README.md
%{_bindir}/cartopy_feature_download


%changelog
* Mon Mar 03 2025 wally <wally> 0.24.1-3.mga10
+ Revision: 2159639
- rebuild for python3.13

* Sat Dec 28 2024 wally <wally> 0.24.1-2.mga10
+ Revision: 2130873
- rebuild with rpm-mageia-setup 2.82

* Sat Dec 07 2024 eatdirt <eatdirt> 0.24.1-1.mga10
+ Revision: 2122533
- Update to version 0.24.1

* Sun May 05 2024 eatdirt <eatdirt> 0.23.0-1.mga10
+ Revision: 2062302
- Update to version 0.23.0

* Fri Feb 23 2024 daviddavid <daviddavid> 0.22.0-1.mga10
+ Revision: 2043385
- new version: 0.22.0
- switch to pyproject
- rebuild for py3.12

* Thu Jan 12 2023 eatdirt <eatdirt> 0.21.1-1.mga9
+ Revision: 1932623
- Update to version 0.21.1

* Thu Sep 29 2022 neoclust <neoclust> 0.21.0-1.mga9
+ Revision: 1893182
- New version 0.21.0

* Fri Aug 26 2022 eatdirt <eatdirt> 0.20.3-2.mga9
+ Revision: 1880514
- Update to version 0.20.3

* Sun May 08 2022 eatdirt <eatdirt> 0.20.2-1.mga9
+ Revision: 1856896
- Upgrade to version 0.20.2

* Wed Apr 06 2022 umeabot <umeabot> 0.19.0.post1-3.mga9
+ Revision: 1846140
- Mageia 9 Mass Rebuild

* Sat Feb 26 2022 mrambo3501 <mrambo3501> 0.19.0.post1-2.mga9
+ Revision: 1785630
- rebuild for python-3.10

* Fri Aug 27 2021 eatdirt <eatdirt> 0.19.0.post1-1.mga9
+ Revision: 1742915
- Upgrade to version 0.19.0.post1

* Tue Apr 20 2021 daviddavid <daviddavid> 0.18.0-2.mga9
+ Revision: 1717416
- rebuild for python 3.9

* Sat Jul 11 2020 eatdirt <eatdirt> 0.18.0-1.mga8
+ Revision: 1605147
- Upgrade to version 0.18.0

* Sun May 10 2020 daviddavid <daviddavid> 0.17.0-7.mga8
+ Revision: 1582757
- rebuild for updated python deps

* Fri Mar 20 2020 eatdirt <eatdirt> 0.17.0-6.mga8
+ Revision: 1558177
- Rebuild for new libproj

* Sun Feb 16 2020 umeabot <umeabot> 0.17.0-5.mga8
+ Revision: 1533123
- Mageia 8 Mass Rebuild

* Wed Sep 18 2019 tv <tv> 0.17.0-4.mga8
+ Revision: 1443588
- rebuild for python-3.8
- drop python2 subpkg

* Sat Mar 09 2019 eatdirt <eatdirt> 0.17.0-3.mga7
+ Revision: 1373339
- Fix python3 compilation
- Fix compilation against libproj 6.0
- Rebuild for new proj

* Tue Jan 08 2019 shlomif <shlomif> 0.17.0-1.mga7
+ Revision: 1351567
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 0.16.0-2.mga7
+ Revision: 1300452
- Mageia 7 Mass Rebuild

* Sun May 13 2018 eatdirt <eatdirt> 0.16.0-1.mga7
+ Revision: 1229080
- Upgrade to version 0.16.0

* Sat Mar 17 2018 daviddavid <daviddavid> 0.15.1-3.mga7
+ Revision: 1210101
- rebuild for new proj 5.0.0
- rename python-cartopy to python2-cartopy

* Tue Nov 21 2017 tv <tv> 0.15.1-2.mga7
+ Revision: 1178364
- rebuild for new libproj

* Fri Oct 27 2017 eatdirt <eatdirt> 0.15.1-1.mga7
+ Revision: 1173968
- imported package python-cartopy


 * Wed Oct 25 2017 Eatdirt <eatdirt@mageia.org> 0.15.1-1.mga7
 - Importing package Cartopy
